# Copyright (C) 2014-2017 MongoDB, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'mongo/operation/commands/command'
require 'mongo/operation/commands/find'
require 'mongo/operation/commands/count'
require 'mongo/operation/commands/distinct'
require 'mongo/operation/commands/explain'
require 'mongo/operation/commands/get_more'
require 'mongo/operation/commands/parallel_scan'
require 'mongo/operation/commands/aggregate'
require 'mongo/operation/commands/map_reduce'
require 'mongo/operation/commands/collections_info'
require 'mongo/operation/commands/create'
require 'mongo/operation/commands/drop'
require 'mongo/operation/commands/drop_database'
require 'mongo/operation/commands/indexes'
require 'mongo/operation/commands/list_collections'
require 'mongo/operation/commands/list_indexes'
require 'mongo/operation/commands/users_info'
